#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from onf_website.component.hearing import IHearingInfo
from onf_website.skin.public.layer import IONFBaseLayer
from pyams_content.features.header import IHeaderSettings, IHeaderTarget
from pyams_content.features.search import ISearchFolder
from pyams_content.shared.common import IWfSharedContent
from pyams_content.shared.common.portlet.interfaces import ISharedContentHeadViewletManager, \
    ISharedContentHeaderPortletSettings
from pyams_default_theme.features.search.portlet import SearchResultsPortletDefaultRenderer
from pyams_default_theme.interfaces import ISearchResultsView
from pyams_default_theme.shared.common.portlet.head import SharedContentHeaderPortletRenderer
from pyams_portal.interfaces import IPortletRenderer
from pyams_sequence.reference import get_reference_target
from pyams_skin.interfaces.viewlet import IBreadcrumbs
from pyams_skin.viewlet.breadcrumb import BreadcrumbsAdapter as BaseBreadcrumbsAdapter
from pyams_template.template import override_template, template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.traversing import get_parent
from pyams_viewlet.viewlet import Viewlet, viewlet_config
from pyams_workflow.interfaces import IWorkflowPublicationInfo


@adapter_config(context=(ISearchFolder, IONFBaseLayer, Interface, ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head.pt', layer=IONFBaseLayer)
class SearchFolderHeaderPortletRenderer(SharedContentHeaderPortletRenderer):
    """Search folder header portlet default renderer"""


@viewlet_config(name='search-folder-head', context=ISearchFolder, layer=IONFBaseLayer, view=Interface,
                manager=ISharedContentHeadViewletManager, weight=1)
@template_config(template='templates/head-specificities.pt', layer=IONFBaseLayer)
class SearchFolderHeadViewlet(Viewlet):
    """Search folder head specificities viewlet"""

    @property
    def search_target(self):
        header_target = get_parent(self.context, IHeaderTarget)
        settings = IHeaderSettings(header_target)
        while settings.inherit:
            settings = IHeaderSettings(settings.parent)
        renderer_settings = settings.settings
        search_target = getattr(renderer_settings, 'search_target', None)
        if search_target is not None:
            return get_reference_target(search_target, request=self.request)


override_template(context=SearchResultsPortletDefaultRenderer,
                  template='templates/search-results.pt', layer=IONFBaseLayer)


@adapter_config(context=(IWfSharedContent, IONFBaseLayer, ISearchResultsView), provides=IBreadcrumbs)
class BreadcrumbsAdapter(BaseBreadcrumbsAdapter):
    """Custom search results breadcrumbs adapter"""

    @property
    def items(self):
        hearing = IHearingInfo(self.context, None)
        if hearing is not None:
            source = hearing.get_source_folder()
            if source is None:
                source = hearing.get_source_site()
            if source is not None:
                publication_info = IWorkflowPublicationInfo(source)
                if publication_info.is_visible(self.request):
                    yield from self.get_items(source)
